@@ -13,7 +13,7 @@ import (
 
 func TestKeyAuth(t *testing.T) {
 	e := echo.New()
-	req := httptest.NewRequest(echo.GET, "/", nil)
+	req := httptest.NewRequest(http.MethodGet, "/", nil)
 	rec := httptest.NewRecorder()
 	c := e.NewContext(req, rec)
 	config := KeyAuthConfig{
@@ -25,21 +25,23 @@ func TestKeyAuth(t *testing.T) {
 		return c.String(http.StatusOK, "test")
 	})
 
+	assert := assert.New(t)
+
 	// Valid key
 	auth := DefaultKeyAuthConfig.AuthScheme + " " + "valid-key"
 	req.Header.Set(echo.HeaderAuthorization, auth)
-	assert.NoError(t, h(c))
+	assert.NoError(h(c))
 
 	// Invalid key
 	auth = DefaultKeyAuthConfig.AuthScheme + " " + "invalid-key"
 	req.Header.Set(echo.HeaderAuthorization, auth)
 	he := h(c).(*echo.HTTPError)
-	assert.Equal(t, http.StatusUnauthorized, he.Code)
+	assert.Equal(http.StatusUnauthorized, he.Code)
 
 	// Missing Authorization header
 	req.Header.Del(echo.HeaderAuthorization)
 	he = h(c).(*echo.HTTPError)
-	assert.Equal(t, http.StatusBadRequest, he.Code)
+	assert.Equal(http.StatusBadRequest, he.Code)
 
 	// Key from custom header
 	config.KeyLookup = "header:API-Key"
@@ -47,7 +49,7 @@ func TestKeyAuth(t *testing.T) {
 		return c.String(http.StatusOK, "test")
 	})
 	req.Header.Set("API-Key", "valid-key")
-	assert.NoError(t, h(c))
+	assert.NoError(h(c))
 
 	// Key from query string
 	config.KeyLookup = "query:key"
@@ -57,7 +59,7 @@ func TestKeyAuth(t *testing.T) {
 	q := req.URL.Query()
 	q.Add("key", "valid-key")
 	req.URL.RawQuery = q.Encode()
-	assert.NoError(t, h(c))
+	assert.NoError(h(c))
 
 	// Key from form
 	config.KeyLookup = "form:key"
@@ -66,8 +68,8 @@ func TestKeyAuth(t *testing.T) {
 	})
 	f := make(url.Values)
 	f.Set("key", "valid-key")
-	req = httptest.NewRequest(echo.POST, "/", strings.NewReader(f.Encode()))
+	req = httptest.NewRequest(http.MethodPost, "/", strings.NewReader(f.Encode()))
 	req.Header.Set(echo.HeaderContentType, echo.MIMEApplicationForm)
 	c = e.NewContext(req, rec)
-	assert.NoError(t, h(c))
+	assert.NoError(h(c))
 }
