@@ -18,32 +18,32 @@ func TestMethodOverride(t *testing.T) {
 	}
 
 	// Override with http header
-	req := httptest.NewRequest(echo.POST, "/", nil)
+	req := httptest.NewRequest(http.MethodPost, "/", nil)
 	rec := httptest.NewRecorder()
-	req.Header.Set(echo.HeaderXHTTPMethodOverride, echo.DELETE)
+	req.Header.Set(echo.HeaderXHTTPMethodOverride, http.MethodDelete)
 	c := e.NewContext(req, rec)
 	m(h)(c)
-	assert.Equal(t, echo.DELETE, req.Method)
+	assert.Equal(t, http.MethodDelete, req.Method)
 
 	// Override with form parameter
 	m = MethodOverrideWithConfig(MethodOverrideConfig{Getter: MethodFromForm("_method")})
-	req = httptest.NewRequest(echo.POST, "/", bytes.NewReader([]byte("_method="+echo.DELETE)))
+	req = httptest.NewRequest(http.MethodPost, "/", bytes.NewReader([]byte("_method="+http.MethodDelete)))
 	rec = httptest.NewRecorder()
 	req.Header.Set(echo.HeaderContentType, echo.MIMEApplicationForm)
 	c = e.NewContext(req, rec)
 	m(h)(c)
-	assert.Equal(t, echo.DELETE, req.Method)
+	assert.Equal(t, http.MethodDelete, req.Method)
 
 	// Override with query parameter
 	m = MethodOverrideWithConfig(MethodOverrideConfig{Getter: MethodFromQuery("_method")})
-	req = httptest.NewRequest(echo.POST, "/?_method="+echo.DELETE, nil)
+	req = httptest.NewRequest(http.MethodPost, "/?_method="+http.MethodDelete, nil)
 	rec = httptest.NewRecorder()
 	c = e.NewContext(req, rec)
 	m(h)(c)
-	assert.Equal(t, echo.DELETE, req.Method)
+	assert.Equal(t, http.MethodDelete, req.Method)
 
 	// Ignore `GET`
-	req = httptest.NewRequest(echo.GET, "/", nil)
-	req.Header.Set(echo.HeaderXHTTPMethodOverride, echo.DELETE)
-	assert.Equal(t, echo.GET, req.Method)
+	req = httptest.NewRequest(http.MethodGet, "/", nil)
+	req.Header.Set(echo.HeaderXHTTPMethodOverride, http.MethodDelete)
+	assert.Equal(t, http.MethodGet, req.Method)
 }
