@@ -14,7 +14,7 @@ func TestRecover(t *testing.T) {
 	e := echo.New()
 	buf := new(bytes.Buffer)
 	e.Logger.SetOutput(buf)
-	req := httptest.NewRequest(echo.GET, "/", nil)
+	req := httptest.NewRequest(http.MethodGet, "/", nil)
 	rec := httptest.NewRecorder()
 	c := e.NewContext(req, rec)
 	h := Recover()(echo.HandlerFunc(func(c echo.Context) error {
