@@ -15,12 +15,12 @@ type (
 		// XSSProtection provides protection against cross-site scripting attack (XSS)
 		// by setting the `X-XSS-Protection` header.
 		// Optional. Default value "1; mode=block".
-		XSSProtection string `json:"xss_protection"`
+		XSSProtection string `yaml:"xss_protection"`
 
 		// ContentTypeNosniff provides protection against overriding Content-Type
 		// header by setting the `X-Content-Type-Options` header.
 		// Optional. Default value "nosniff".
-		ContentTypeNosniff string `json:"content_type_nosniff"`
+		ContentTypeNosniff string `yaml:"content_type_nosniff"`
 
 		// XFrameOptions can be used to indicate whether or not a browser should
 		// be allowed to render a page in a <frame>, <iframe> or <object> .
@@ -32,27 +32,27 @@ type (
 		// - "SAMEORIGIN" - The page can only be displayed in a frame on the same origin as the page itself.
 		// - "DENY" - The page cannot be displayed in a frame, regardless of the site attempting to do so.
 		// - "ALLOW-FROM uri" - The page can only be displayed in a frame on the specified origin.
-		XFrameOptions string `json:"x_frame_options"`
+		XFrameOptions string `yaml:"x_frame_options"`
 
 		// HSTSMaxAge sets the `Strict-Transport-Security` header to indicate how
 		// long (in seconds) browsers should remember that this site is only to
 		// be accessed using HTTPS. This reduces your exposure to some SSL-stripping
 		// man-in-the-middle (MITM) attacks.
 		// Optional. Default value 0.
-		HSTSMaxAge int `json:"hsts_max_age"`
+		HSTSMaxAge int `yaml:"hsts_max_age"`
 
 		// HSTSExcludeSubdomains won't include subdomains tag in the `Strict Transport Security`
 		// header, excluding all subdomains from security policy. It has no effect
 		// unless HSTSMaxAge is set to a non-zero value.
 		// Optional. Default value false.
-		HSTSExcludeSubdomains bool `json:"hsts_exclude_subdomains"`
+		HSTSExcludeSubdomains bool `yaml:"hsts_exclude_subdomains"`
 
 		// ContentSecurityPolicy sets the `Content-Security-Policy` header providing
 		// security against cross-site scripting (XSS), clickjacking and other code
 		// injection attacks resulting from execution of malicious content in the
 		// trusted web page context.
 		// Optional. Default value "".
-		ContentSecurityPolicy string `json:"content_security_policy"`
+		ContentSecurityPolicy string `yaml:"content_security_policy"`
 	}
 )
 
