@@ -11,18 +11,20 @@ import (
 
 func TestAddTrailingSlash(t *testing.T) {
 	e := echo.New()
-	req := httptest.NewRequest(echo.GET, "/add-slash", nil)
+	req := httptest.NewRequest(http.MethodGet, "/add-slash", nil)
 	rec := httptest.NewRecorder()
 	c := e.NewContext(req, rec)
 	h := AddTrailingSlash()(func(c echo.Context) error {
 		return nil
 	})
 	h(c)
-	assert.Equal(t, "/add-slash/", req.URL.Path)
-	assert.Equal(t, "/add-slash/", req.RequestURI)
+
+	assert := assert.New(t)
+	assert.Equal("/add-slash/", req.URL.Path)
+	assert.Equal("/add-slash/", req.RequestURI)
 
 	// With config
-	req = httptest.NewRequest(echo.GET, "/add-slash?key=value", nil)
+	req = httptest.NewRequest(http.MethodGet, "/add-slash?key=value", nil)
 	rec = httptest.NewRecorder()
 	c = e.NewContext(req, rec)
 	h = AddTrailingSlashWithConfig(TrailingSlashConfig{
@@ -31,24 +33,27 @@ func TestAddTrailingSlash(t *testing.T) {
 		return nil
 	})
 	h(c)
-	assert.Equal(t, http.StatusMovedPermanently, rec.Code)
-	assert.Equal(t, "/add-slash/?key=value", rec.Header().Get(echo.HeaderLocation))
+	assert.Equal(http.StatusMovedPermanently, rec.Code)
+	assert.Equal("/add-slash/?key=value", rec.Header().Get(echo.HeaderLocation))
 }
 
 func TestRemoveTrailingSlash(t *testing.T) {
 	e := echo.New()
-	req := httptest.NewRequest(echo.GET, "/remove-slash/", nil)
+	req := httptest.NewRequest(http.MethodGet, "/remove-slash/", nil)
 	rec := httptest.NewRecorder()
 	c := e.NewContext(req, rec)
 	h := RemoveTrailingSlash()(func(c echo.Context) error {
 		return nil
 	})
 	h(c)
-	assert.Equal(t, "/remove-slash", req.URL.Path)
-	assert.Equal(t, "/remove-slash", req.RequestURI)
+
+	assert := assert.New(t)
+
+	assert.Equal("/remove-slash", req.URL.Path)
+	assert.Equal("/remove-slash", req.RequestURI)
 
 	// With config
-	req = httptest.NewRequest(echo.GET, "/remove-slash/?key=value", nil)
+	req = httptest.NewRequest(http.MethodGet, "/remove-slash/?key=value", nil)
 	rec = httptest.NewRecorder()
 	c = e.NewContext(req, rec)
 	h = RemoveTrailingSlashWithConfig(TrailingSlashConfig{
@@ -57,16 +62,16 @@ func TestRemoveTrailingSlash(t *testing.T) {
 		return nil
 	})
 	h(c)
-	assert.Equal(t, http.StatusMovedPermanently, rec.Code)
-	assert.Equal(t, "/remove-slash?key=value", rec.Header().Get(echo.HeaderLocation))
+	assert.Equal(http.StatusMovedPermanently, rec.Code)
+	assert.Equal("/remove-slash?key=value", rec.Header().Get(echo.HeaderLocation))
 
 	// With bare URL
-	req = httptest.NewRequest(echo.GET, "http://localhost", nil)
+	req = httptest.NewRequest(http.MethodGet, "http://localhost", nil)
 	rec = httptest.NewRecorder()
 	c = e.NewContext(req, rec)
 	h = RemoveTrailingSlash()(func(c echo.Context) error {
 		return nil
 	})
 	h(c)
-	assert.Equal(t, "", req.URL.Path)
+	assert.Equal("", req.URL.Path)
 }
